@@ -1,4 +1,4 @@
-"""Navigation Items to add to Nautobot for nautobot_plugin_ip_services."""
+"""Navigation Items to add to Nautobot for nautobot-plugin-ip-services."""
 
 from nautobot.extras.plugins import PluginMenuButton, PluginMenuItem
 from nautobot.utilities.choices import ButtonColorChoices
@@ -6,12 +6,12 @@ from nautobot.utilities.choices import ButtonColorChoices
 """
 menu_items = (
     PluginMenuItem(
-        link='plugins:nautobot_plugin_ip_services:model',  # A reverse compatible link to follow.
+        link='plugins:nautobot-plugin-ip-services:model',  # A reverse compatible link to follow.
         link_text = 'Sample Text',  # Text to display to user.
         permissions = [],  # Optional: List of permissions required to display this link.
         buttons = (  # Optional: Iterable of PluginMenuButton instances to display.
             PluginMenuButton(
-                'plugins:nautobot_plugin_ip_services:model',  # A reverse compatible link to follow.
+                'plugins:nautobot-plugin-ip-services:model',  # A reverse compatible link to follow.
                 'Sample Text',  # Text to display to user.
                 'mdi mdi-help-circle',  # Button icon CSS Classes (Currently supports Material Design Icons.)
                 ButtonColorChoices.BLUE,  # Optional: Color for the button.,
